#!/bin/bash
#--------------------------------------------------------------------------
# /var/install/config.d/havp-update.sh - parameter update script
#
# Creation: 2010-08-21 OJae
# Last Update: 2010-08-21 OJae
#
# Copyright (c) 2010 Olaf Jaehrling eisfair(at)ojaehrling(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License
#--------------------------------------------------------------------------
package='havp'
package_name='havp'

# include eislib
if [ -f /var/install/include/check-eisfair-version ]
then
    . /var/install/include/check-eisfair-version
    . /var/install/include/eislib
    . /var/install/include/configlib
fi
#exec 2>/tmp/B_F_b_up-trace.log
#set -x
mecho -info "adding new parameter(s) ..."
### ---------------------------------------------------------------------------
### Set the default values for configuration
### ---------------------------------------------------------------------------


START_HAVP='yes'
HAVP_USER='clamav'
HAVP_GROUP='users'
HAVP_ROTATE_COUNT='10'
HAVP_ROTATE_INTERVAL='monthly'
HAVP_SCANTEMPFILE='/tmp/havp/havp-XXXXXX'
HAVP_TEMPDIR='/tmp'
HAVP_PORT='1007'
HAVP_TEMPLATEPATH='/usr/local/havp/templates/de'
HAVP_WHITELIST='/usr/local/havp/whitelist'
HAVP_BLACKLIST='/usr/local/havp/blacklist'
HAVP_MAXSCANSIZE='10000000'
HAVP_KEEPBACKBUFFER='1000000'
HAVP_TRICKLING='10'
HAVP_SERVERNUMBER='8'
HAVP_MAXSERVERS='10'
HAVP_ALLOW_RESUME='no'
if [ "$EISFAIR_SYSTEM" = "eisfair-1" ]
then
    HAVP_USE_SQUID='yes'
elif [ "$EISFAIR_SYSTEM" = "eisfair-2" ]
then
    HAVP_USE_SQUID='no'
fi
HAVP_USE_STANDALONE='no'
HAVP_TRANSPARENT='no'
HAVP_SET_IPTABLES_RULE='yes'
HAVP_ENABLECLAMLIB='yes'
HAVP_CLAMMAXSCANSIZE='100'
HAVP_CLAMMAXFILES='10000'
HAVP_CLAMMAXFILESIZE='25'
HAVP_CLAMMAXRECURSION='16'
HAVP_CLAMSOCKET='/run/clamd'
HAVP_ENABLEFPROT='no'
HAVP_FPROTSERVER='127.0.0.1'
HAVP_FPROTPORT='10200'
HAVP_FPROTOPTIONS='--scanlevel=2 --heurlevel=2'

### ---------------------------------------------------------------------------
### read old configuration and rename old variables
### ---------------------------------------------------------------------------
read_old_variables()
{
 # read old values
 if [ -f /etc/config.d/${package_name} ]
 then
     . /etc/config.d/${package_name}
 fi
}
#------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------
mecho -info "modifying parameter(s) ..."
mecho -warn "... read documentation for modified and/or added parameter(s)!"

modify_variables ()
{
 echo "nothing to do" >/dev/null
}

### ---------------------------------------------------------------------------
### Write config and default files
### ---------------------------------------------------------------------------
make_config_file()
{
 internal_conf_file=${1}
 (
 #--------------------------------------------------------------------------------
 printgpl -conf ${package_name} "2010-08-21" "OJae" "2010 Olaf Jaehrling eisfair(at)ojaehrling(dot)de"
 #--------------------------------------------------------------------------------
 #--------------------------------------------------------------------------------
 printgroup "HAVP  common configuration"
 #--------------------------------------------------------------------------------
 printvar "START_HAVP" "start havp yes/no"
 printvar "HAVP_USER"
 printvar "HAVP_GROUP"
 printvar "HAVP_ROTATE_COUNT"
 printvar "HAVP_ROTATE_INTERVAL"
 printvar "HAVP_SCANTEMPFILE"
 printvar "HAVP_TEMPDIR"
 printvar "HAVP_PORT"
 printvar "HAVP_TEMPLATEPATH"
 printvar "HAVP_WHITELIST"
 printvar "HAVP_BLACKLIST"
 printvar "HAVP_MAXSCANSIZE"
 printvar "HAVP_KEEPBACKBUFFER"
 printvar "HAVP_TRICKLING"
 printvar "HAVP_SERVERNUMBER"
 printvar "HAVP_MAXSERVERS"
 printvar "HAVP_ALLOW_RESUME"
 printvar "HAVP_USE_SQUID"
 printvar "HAVP_USE_STANDALONE"
 printvar "HAVP_SET_IPTABLES_RULE"
 printvar "HAVP_TRANSPARENT"
 printvar "HAVP_ENABLECLAMLIB"
 printvar "HAVP_CLAMMAXSCANSIZE"
 printvar "HAVP_CLAMMAXFILES"
 printvar "HAVP_CLAMMAXFILESIZE"
 printvar "HAVP_CLAMMAXRECURSION"
 printvar "HAVP_CLAMSOCKET"
 printvar "HAVP_ENABLEFPROT"
 printvar "HAVP_FPROTSERVER"
 printvar "HAVP_FPROTPORT"
 printvar "HAVP_FPROTOPTIONS"

 #--------------------------------------------------------------------------------
 printend
 #--------------------------------------------------------------------------------

 ) > ${internal_conf_file}
 # Set rights
 chmod 0600 ${internal_conf_file}
 chown root ${internal_conf_file}
}

### -------------------------------------------------------------------------
### Create the check.d file
### -------------------------------------------------------------------------

make_check_file()
{
#--------------------------------------------------------------------------------
printgpl -check ${package_name} "2010-08-21" "OJae" "2010 Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package_name}
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package_name} <<EOF
# Variable OPT_VARIABLE VARIABLE_N VALUE
START_HAVP		-                               -		YESNO
+HAVP_USER		START_HAVP			-		NOTEMPTY  
+HAVP_GROUP		START_HAVP                      -		NOTEMPTY
HAVP_ROTATE_INTERVAL	START_HAVP			-		LOG_INTERVAL
HAVP_ROTATE_COUNT	START_HAVP			-		NUMERIC
HAVP_SCANTEMPFILE	START_HAVP                      -		HAVP_PATH
HAVP_TEMPDIR		START_HAVP                      -		ABS_PATH
HAVP_PORT		START_HAVP                      -		NUMERIC
HAVP_TEMPLATEPATH	START_HAVP                      -		ABS_PATH
HAVP_WHITELIST		START_HAVP                      -		ABS_PATH
HAVP_BLACKLIST		START_HAVP                      -		ABS_PATH
HAVP_MAXSCANSIZE	START_HAVP                      -		NUMERIC
HAVP_KEEPBACKBUFFER	START_HAVP                      -		NUMERIC
HAVP_TRICKLING		START_HAVP                      -		NUMERIC
HAVP_SERVERNUMBER       START_HAVP                      -               NUMERIC
HAVP_MAXSERVERS         START_HAVP                      -               NUMERIC
HAVP_ALLOW_RESUME	START_HAVP			-		YESNO
HAVP_USE_SQUID		START_HAVP                      -		YESNO
HAVP_USE_STANDALONE	START_HAVP			-		YESNO
HAVP_SET_IPTABLES_RULE	HAVP_USE_STANDALONE		-		YESNO
HAVP_TRANSPARENT	HAVP_USE_STANDALONE		-		YESNO
HAVP_ENABLECLAMLIB	START_HAVP                      -		YESNO
HAVP_CLAMMAXSCANSIZE	HAVP_ENABLECLAMLIB		-		NUMERIC
HAVP_CLAMMAXFILES	HAVP_ENABLECLAMLIB		-		NUMERIC
HAVP_CLAMMAXFILESIZE	HAVP_ENABLECLAMLIB		-		NUMERIC
HAVP_CLAMMAXRECURSION   HAVP_ENABLECLAMLIB              -               NUMERIC
HAVP_CLAMSOCKET		HAVP_ENABLECLAMLIB		-		ABS_PATH
HAVP_ENABLEFPROT	START_HAVP                      -		YESNO
HAVP_FPROTSERVER	HAVP_ENABLEFPROT		-		ABS_PATH
HAVP_FPROTOPTIONS	HAVP_ENABLEFPROT		-		NONE
HAVP_FPROTPORT		HAVP_ENABLEFPROT		-		NUMERIC

EOF

 # Set rights for check.d file
 chmod 0600 /etc/check.d/${package_name}
 chown root /etc/check.d/${package_name}
}
## -------------------------------------------------------------------------
### Create the exp file
### -------------------------------------------------------------------------
make_exp_file()
{
#--------------------------------------------------------------------------------
printgpl -check_exp ${package_name} "2010-08-21" "OJae" "2010 Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package_name}.exp
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package_name}.exp <<EOF
HAVP_PATH = '(RE:ABS_PATH)/(havp-XXXXXX)' : 'only complete path ended with /havp-XXXXXX as File, like /tmp/havp/havp-XXXXXX'
EOF

 # Set rights for exp file
 chmod 0600 /etc/check.d/${package_name}.exp
 chown root /etc/check.d/${package_name}.exp
}
### -------------------------------------------------------------------------
### Create the ext file
### -------------------------------------------------------------------------

#make_ext_file()
#{
#--------------------------------------------------------------------------------
#printgpl -check_ext ${package_name} "2010-08-21" "OJae" "2010 Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package_name}.ext
#--------------------------------------------------------------------------------
#cat >>/etc/check.d/${package_name}.ext <<EOF
#
#
#
#EOF
#
# # Set rights for exp file
# chmod 0600 /etc/check.d/${package_name}.ext
# chown root /etc/check.d/${package_name}.ext
#}



### ---------------------------------------------------------------------------
### Main
### ---------------------------------------------------------------------------

# update from old version
read_old_variables

# modify variables from old version
modify_variables

# write new config file
make_config_file /etc/config.d/${package}

# write default config file
make_config_file /etc/default.d/${package}

# write check.d file
make_check_file

# write *.exp file
make_exp_file

# write *.ext file
#make_ext_file

anykey
exit 0

### ---------------------------------------------------------------------------
### End
###----------------------------------------------------------------------------

